@@ -93,6 +93,7 @@ find_statistic <- function(x, ...) {
       "averaging",
       "betareg",
       "bife",
+      "boot_test_mediation",
       "bracl",
       "brglm",
       "brglmFit",
@@ -123,6 +124,7 @@ find_statistic <- function(x, ...) {
       "loggammacenslmrob",
       "LORgee",
       "lrm",
+      "metaplus",
       "mixor",
       "MixMod",
       "mjoint",
@@ -135,11 +137,14 @@ find_statistic <- function(x, ...) {
       "nlreg",
       "objectiveML",
       "psm",
+      "robmixglm",
       "rma",
+      "rma.mv",
       "rma.uni",
       "sem",
       "slm",
       "survreg",
+      "test_mediation",
       "tobit",
       "vglm",
       "wbgee",
