@@ -23,6 +23,7 @@ is_model <- function(x) {
     c(
       "_ranger",
       "aareg",
+      "afex_aov",
       "anova",
       "Anova.mlm",
       "aov",
@@ -44,6 +45,7 @@ is_model <- function(x) {
       "bigglm",
       "blavaan",
       "blmerMod",
+      "boot_test_mediation",
       "bracl",
       "brglm",
       "brglmFit",
@@ -80,6 +82,7 @@ is_model <- function(x) {
       "felm",
       "fitdistr",
       "fixest",
+      "flexmix",
       "flexsurvreg",
       "gam",
       "Gam",
@@ -142,9 +145,14 @@ is_model <- function(x) {
       "mclogit",
       "mmclogit",
       "mcmc",
+      "mcmc.list",
       "MCMCglmm",
       "mediate",
       "merMod",
+      "meta_fixed",
+      "meta_random",
+      "meta_ordered",
+      "metaplus",
       "mixed",
       "mixor",
       "MixMod",
@@ -176,6 +184,7 @@ is_model <- function(x) {
       "rma",
       "rma.uni",
       "rms",
+      "robmixglm",
       "rq",
       "rqss",
       "sem",
@@ -189,6 +198,7 @@ is_model <- function(x) {
       "survPresmooth",
       "svyglm",
       "svyolr",
+      "test_mediation",
       "tobit",
       "truncreg",
       "vgam",
