@@ -148,6 +148,15 @@ n_obs.gbm <- function(x, ...) {
 }
 
 
+#' @export
+n_obs.afex_aov <- function(x, ...) {
+  if ("aov" %in% names(x)) {
+    n_obs(x$aov)
+  } else {
+    n_obs(x$lm)
+  }
+}
+
 
 #' @export
 n_obs.glimML <- function(x, ...) {
